@@ -13,8 +13,8 @@ def parseHTML(authenticatedUser, html):
     Parameters
     ----------
     authenticatedUser (:)
-        An authenticated Labstep :class:`~labstep.user.User`
-        (see :func:`~labstep.user.authenticate`)
+        An authenticated Labstep :class:`~labstep.entities.user.model.User`
+        (see :func:`~labstep.authenticate`)
     html (str)
         HTML to be converted (as a string).
     """
