@@ -681,6 +681,51 @@ class Experiment(EntityPrimary):
 
         return experimentRepository.exportExperiment(self, path)
 
+    def getJupyterNotebooks(self, count=100):
+        """
+        Retrieve the Jupyter Notebooks attached to this Labstep Entity.
+
+        Returns
+        -------
+        List[:class:`~labstep.entities.jupyterNotebook.model.JupyterNotebook`]
+            List of the Jupyter Notebooks attached.
+
+        Example
+        -------
+        ::
+
+            entity = user.getExperiment(17000)
+            jupyter_notebooks = entity.getJupyterNotebooks()
+            print(jupyter_notebooks[0])
+        """
+        return self.root_experiment.getJupyterNotebooks()
+
+    def addJupyterNotebook(self, name=UNSPECIFIED, data=UNSPECIFIED):
+        """
+        Add a Jupyter Notebook to an experiment entry.
+
+        Parameters
+        ----------
+        name (str)
+            Name of Jupyter Notebook
+        data (JSON)
+            JSON Jupyter Notebook structure
+
+        Returns
+        -------
+        :class:`~labstep.entities.jupyterNotebook.model.JupyterNotebook`
+            The newly added file entity.
+
+        Example
+        -------
+        ::
+
+            experiment = user.getExperiment(17000)
+            experiment.addJupyterNotebook()
+        """
+
+        return self.root_experiment.addJupyterNotebook(name, data)
+
     @deprecated(version='3.3.2', reason="You should use experiment.addDataField instead")
     def addDataElement(self, *args, **kwargs):
         return self.addDataField(*args, **kwargs)
