@@ -7,10 +7,15 @@ import labstep.generic.entity.repository as entityRepository
 from labstep.constants import UNSPECIFIED
 
 
-def newJupyterNotebook(user, name=UNSPECIFIED, data=UNSPECIFIED):
-    return entityRepository.newEntity(user, JupyterNotebook, {"name": name, "data": data})
+def newJupyterNotebook(user, name=UNSPECIFIED, data=UNSPECIFIED, extraParams={}):
+    params = {"name": name, 'data':data, **extraParams}
+    return entityRepository.newEntity(user, JupyterNotebook, params)
 
 
+def getJupyterNotebooks(user, count=100, extraParams={}):
+    params = {**extraParams}
+    return entityRepository.getEntities(user, JupyterNotebook, count, params)
+
 def getJupyterNotebook(user, guid):
     return entityRepository.getEntity(user, JupyterNotebook, id=guid)
 
