@@ -7,6 +7,7 @@ import labstep.generic.entity.repository as entityRepository
 from labstep.generic.entityList.model import EntityList
 from labstep.service.helpers import handleDate, handleString
 from labstep.entities.metadata.model import Metadata, FIELDS, ALLOWED_FIELDS
+from labstep.constants import UNSPECIFIED
 
 
 def getMetadata(entity, count=1000, extraParams={}):
@@ -26,17 +27,17 @@ def addMetadataTo(
     entity,
     fieldName,
     fieldType="default",
-    value=None,
-    date=None,
-    number=None,
-    unit=None,
-    filepath=None,
+    value=UNSPECIFIED,
+    date=UNSPECIFIED,
+    number=UNSPECIFIED,
+    unit=UNSPECIFIED,
+    filepath=UNSPECIFIED,
     extraParams={},
 ):
-    if filepath is not None:
+    if filepath is not UNSPECIFIED:
         fileId = fileRepository.newFile(entity.__user__, filepath).id
     else:
-        fileId = None
+        fileId = UNSPECIFIED
 
     if fieldType not in FIELDS:
         msg = "Not a supported metadata type '{}'".format(fieldType)
@@ -50,7 +51,7 @@ def addMetadataTo(
         "unit": unit,
         "file_id": fileId,
     }
-    fields = {k: v for k, v in fields.items() if v}
+    fields = {k: v for k, v in fields.items() if v is not UNSPECIFIED}
     fields = set(fields.keys())
     violations = fields - allowedFieldsForType
     if violations:
@@ -74,7 +75,7 @@ def addMetadataTo(
     return entityRepository.newEntity(entity.__user__, Metadata, params)
 
 
-def editMetadata(metadata, fieldName=None, value=None, extraParams={}):
+def editMetadata(metadata, fieldName=UNSPECIFIED, value=UNSPECIFIED, extraParams={}):
     params = {
         "label": handleString(fieldName),
         "value": handleString(value),
