@@ -7,6 +7,7 @@ from labstep.generic.entity.model import Entity
 import labstep.generic.entity.repository as entityRepository
 import labstep.entities.workspace.repository as workspaceRepository
 import labstep.entities.invitation.repository as invitationRepository
+from labstep.constants import UNSPECIFIED
 
 
 class Organization(Entity):
@@ -36,7 +37,7 @@ class Organization(Entity):
 
         return organizationRepository.editOrganization(self.__user__, name, extraParams=extraParams)
 
-    def inviteUsers(self, emails, workspace_id=None):
+    def inviteUsers(self, emails, workspace_id=UNSPECIFIED):
         """
         Invite users to your organization.
 
@@ -61,7 +62,7 @@ class Organization(Entity):
                                                    organization_id=self.id,
                                                    workspace_id=workspace_id)
 
-    def getWorkspaces(self, count=100, search_query=None):
+    def getWorkspaces(self, count=100, search_query=UNSPECIFIED):
         """
         Get the workspaces in your Organization
 
