@@ -182,3 +182,18 @@ def dataTableToDataFrame(dataTable):
     df = pandas.DataFrame(values).T.rename(columns=header)
 
     return df
+
+
+def dataFrameToDataTable(df):
+
+    headers = {'0': {str(colInd): {'value': colName}
+                     for colInd, colName in enumerate(df.columns)}}
+
+    dataTable = {
+        str(rowInd): {str(colInd): {'value': row[colName]} for colInd, colName in enumerate(df.columns)} for rowInd, row in df.iterrows()
+    }
+
+    data = {"rowCount": int(df.index[-1]) + 1, "columnCount": len(
+        df.columns), "colHeaderData": {}, "data": {"dataTable": {**headers, **dataTable}}}
+
+    return data
